pub struct RemoteServiceMock { /* private fields */ }Expand description
Provides a simple mock implementation of fuchsia.bluetooth.gatt2.RemoteService.
Implementations
Sourceimpl RemoteServiceMock
impl RemoteServiceMock
pub fn new( timeout: MonotonicDuration, ) -> Result<(RemoteServiceProxy, RemoteServiceMock), Error>
pub fn from_stream( stream: RemoteServiceRequestStream, timeout: MonotonicDuration, ) -> RemoteServiceMock
pub async fn expect_discover_characteristics( &mut self, characteristics: &Vec<Characteristic>, ) -> Result<(), Error>
Sourcepub async fn expect_read_by_type(
&mut self,
expected_uuid: Uuid,
result: Result<&[ReadByTypeResult], Error>,
) -> Result<(), Error>
pub async fn expect_read_by_type( &mut self, expected_uuid: Uuid, result: Result<&[ReadByTypeResult], Error>, ) -> Result<(), Error>
Wait until a Read By Type message is received with the given uuid. result will be sent
in response to the matching FIDL request.
Sourcepub async fn expect_read_characteristic(
&mut self,
expected_handle: u64,
result: Result<&ReadValue, Error>,
) -> Result<(), Error>
pub async fn expect_read_characteristic( &mut self, expected_handle: u64, result: Result<&ReadValue, Error>, ) -> Result<(), Error>
Wait until a Read Characteristic request is received with the given handle, then result
will be sent.
pub async fn expect_register_characteristic_notifier( &mut self, handle: Handle, ) -> Result<ClientEnd<CharacteristicNotifierMarker>, Error>